pub trait ComplexDataSource {
// Required method
fn source_complex_data(&mut self) -> ComPacket;
// Provided method
fn get_state(&self) -> State { ... }
}Required Methods
fn source_complex_data(&mut self) -> ComPacket
Provided Methods
Implementors
impl ComplexDataSource for DemoData
Pull data out of the data loaded into memory from the demo data file. Prepair it for send.
impl ComplexDataSource for DummyData
This is a relic of before we were given data for DemoData